#include <algorithm>
#include <array>
#include <bitset>
#include <cassert>
#include <chrono>
#include <cmath>
#include <cstdint>
#include <cstring>
#include <functional>
#include <iomanip>
#include <iostream>
#include <map>
#include <numeric>
#include <queue>
#include <random>
#include <set>
#include <unordered_set>
#include <utility>
#include <vector>
using namespace std;

using ll = long long;
using ld = long double;
using pii = pair<int, int>;
using vi = vector<int>;
#define rep(i, a, b) for(int i = a; i < (b); ++i)
#define all(x) (x).begin(), (x).end()
#define sz(x) (int)(x).size()
#define smx(a, b) a = max(a, b)
#define smn(a, b) a = min(a, b)
#define pb push_back
#define endl '\n'

const ll MOD = 1e9 + 7;
const ld EPS = 1e-9;

mt19937 rng(time(0));

const ll mod = (119 << 23) + 1, root = 62; // = 998244353
// For p < 2^30 there is also e.g. 5 << 25, 7 << 26, 479 << 21
// and 483 << 21 (same root). The last two are > 10^9.

ll modpow(ll b, ll e) {
	ll ans = 1;
	for (; e; b = b * b % mod, e /= 2)
		if (e & 1) ans = ans * b % mod;
	return ans;
}

typedef vector<ll> vl;
void ntt(vl &a) {
	int n = sz(a), L = 31 - __builtin_clz(n);
	static vl rt(2, 1);
	for (static int k = 2, s = 2; k < n; k *= 2, s++) {
		rt.resize(n);
		ll z[] = {1, modpow(root, mod >> s)};
		rep(i,k,2*k) rt[i] = rt[i / 2] * z[i & 1] % mod;
	}
	vi rev(n);
	rep(i,0,n) rev[i] = (rev[i / 2] | (i & 1) << L) / 2;
	rep(i,0,n) if (i < rev[i]) swap(a[i], a[rev[i]]);
	for (int k = 1; k < n; k *= 2)
		for (int i = 0; i < n; i += 2 * k) rep(j,0,k) {
			ll z = rt[j + k] * a[i + j + k] % mod, &ai = a[i + j];
			a[i + j + k] = ai - z + (z > ai ? mod : 0);
			ai += (ai + z >= mod ? z - mod : z);
		}
}
vl conv(const vl &a, const vl &b) {
	if (a.empty() || b.empty()) return {};
	int s = sz(a) + sz(b) - 1, B = 32 - __builtin_clz(s),
		n = 1 << B;
	int inv = modpow(n, mod - 2);
	vl L(a), R(b), out(n);
	L.resize(n), R.resize(n);
	ntt(L), ntt(R);
	rep(i,0,n)
		out[-i & (n - 1)] = (ll)L[i] * R[i] % mod * inv % mod;
	ntt(out);
	return {out.begin(), out.begin() + s};
}

struct Poly {
	vl poly;
	Poly() = default;
	Poly(vl v): poly(std::move(v)) {}

	int size() const {
		return sz(poly);
	}

	Poly operator+(Poly const& p) const {
		vl out(max(size(), p.size()));
		for (int i = 0; i < size(); i++) {
			out[i] += poly[i];
		}
		for (int i = 0; i < p.size(); i++) {
			out[i] = (out[i] + p.poly[i]) % mod;
		}
		return out;
	}

	Poly operator+=(Poly const& p) {
		if (p.size() > size()) poly.resize(p.size());
		for (int i = 0; i < p.size(); i++) {
			poly[i] = (poly[i] + p.poly[i]) % mod;
		}
		return *this;
	}

	Poly operator*(Poly const& p) const {
		return conv(poly, p.poly);
	}
};

using T = array<array<Poly, 3>, 3>;

int main() {
	cin.tie(0)->sync_with_stdio(0);

	string s; cin >> s;
	int n = sz(s);

	auto dnc = [&](auto self, int a, int b) -> T {
		if (b == a + 1) {
			T out = {};
			if (s[a] == 'B') out[0][0] = Poly{{0, 1}};
			else if (s[a] == 'Y') out[1][1] = Poly{{0, 1}};
			else if (s[a] == 'R') out[2][2] = Poly{{0, 1}};
			return out;
		}
		int mid = (a + b) / 2;
		T left = self(self, a, mid);
		T right = self(self, mid, b);
		T out = {};
		for (int i = 0; i <= 2; i++) {
			for (int j = i; j <= 2; j++) {
				out[i][j] = left[i][j] + right[i][j];
				for (int l = i; l <= j; l++) {
					Poly f;
					for (int m = l; m <= j; m++) {
						f += right[m][j];
					}
					out[i][j] += left[i][l] * f;
				}
			}
		}
		return out;
	};

	T res = dnc(dnc, 0, n);
	Poly total;
	for (int i = 0; i <= 2; i++) {
		for (int j = i; j <= 2; j++) {
			total += res[i][j];
		}
	}

	vector<ll> fact(n + 1);
	fact[0] = 1;
	for (int i = 1; i <= n; i++) {
		fact[i] = (fact[i - 1] * i) % mod;
	}
	vector<ll> ifact(n + 1);
	ifact[n] = modpow(fact[n], mod - 2);
	for (int i = n - 1; i >= 0; --i) {
		ifact[i] = (ifact[i + 1] * (i + 1)) % mod;
	}

	auto iC = [&](int m, int k) {
		if (k > n) return 0ll;
		return ((ifact[m] * fact[k]) % mod * fact[m - k]) % mod;
	};

	ll ans = 0;
	for (int i = 1; i < total.size(); i++) {
		ans += (total.poly[i] * iC(n, i)) % mod;
	}
	ans %= mod;
	ans = (n - ans + mod) % mod;
	cout << ans << "\n";
}
